"use client";
import React from "react";
import Carousel from "react-multi-carousel";
import "react-multi-carousel/lib/styles.css";

const responsive = {
  superLargeDesktop: {
    breakpoint: { max: 4000, min: 3000 },
    items: 1,
    slidesToSlide: 1,
  },
  desktop: {
    breakpoint: { max: 3000, min: 1024 },
    items: 1,
    slidesToSlide: 1,
  },
  tablet: {
    breakpoint: { max: 1024, min: 464 },
    items: 1,
    slidesToSlide: 1,
  },
  mobile: {
    breakpoint: { max: 464, min: 0 },
    items: 1,
    slidesToSlide: 1,
  },
};

const sections = ["Overview", "Location", "Amenities", "Video & Documents"];

const MapAndImages = ({ 
  selectedNav, 
  setSelectedNav, 
  mainImg, 
  thumbImages 
}) => {
  // Function to get the correct image URL with fallback
  const getMainImageUrl = (img) => {
    if (!img) return "/property.png";
    
    // Try fetching the user post image
    const userImgUrl = `http://localhost:8000/user-img/user-post-main-img/${img}`;
    
    // Fetch the image to check if it exists
    fetch(userImgUrl)
      .then(response => {
        if (!response.ok) {
          // If user post image doesn't exist, use developer post image
          return `http://localhost:8000/user-img/developer-post-main/${img}`;
        }
        return userImgUrl;
      })
      .catch(() => {
        // If there's an error, use developer post image
        return `http://localhost:8000/user-img/developer-post-main/${img}`;
      });

    return userImgUrl; // Return user URL by default while checking
  };

  // Function to get the correct thumbnail URL with fallback
  const getThumbImageUrl = (thumb) => {
    if (!thumb) return "/property.png";
    
    // Try fetching the user post thumbnail
    const userThumbUrl = `http://localhost:8000/user-img/user-post-img-thumb/${thumb}`;
    
    // Fetch the thumbnail to check if it exists
    fetch(userThumbUrl)
      .then(response => {
        if (!response.ok) {
          // If user thumbnail doesn't exist, use developer thumbnail
          return `http://localhost:8000/user-img/developer-post-thumb/${thumb}`;
        }
        return userThumbUrl;
      })
      .catch(() => {
        // If there's an error, use developer thumbnail
        return `http://localhost:8000/user-img/developer-post-thumb/${thumb}`;
      });

    return userThumbUrl; // Return user URL by default while checking
  };

  const mainImgUrl = getMainImageUrl(mainImg);
  const thumbImgUrls = thumbImages.map(thumb => getThumbImageUrl(thumb));

  return (
    <div className="bg-white lg:pt-8 pt-4 lg:px-10 px-4 rounded-lg shadow-lg">
      <div className="flex lg:flex-row flex-col gap-8 border-[#DCDCDC] border-b-[1px] pb-4">
        {/* Carousel Section */}
        <div className="rounded-lg overflow-hidden lg:w-1/2 w-full aspect-square">
          <Carousel
            responsive={responsive}
            infinite={true}
            arrows={false}
            ssr={true}
            showDots={true}
            transitionDuration={1000}
            autoPlay={true}
            autoPlaySpeed={1000}
            className="w-full h-full"
            containerClass="h-full"
            itemClass="h-full"
          >
            {/* Main Image */}
            <div className="relative h-full w-full">
              <div className="w-full h-full flex items-center justify-center">
                <img 
                  src={mainImgUrl} 
                  alt="Main Image"
                  className="max-w-full max-h-full object-contain"
                  onError={(e) => {
                    // If image fails to load, try the developer post URL
                    e.target.src = `http://localhost:8000/user-img/developer-post-main/${mainImg}`;
                    // If developer post fails, use default property image
                    e.target.onerror = () => {
                      e.target.src = "/property.png";
                      e.target.onerror = null; // Prevent infinite loop
                    };
                  }}
                />
              </div>
              <div className="absolute top-2 px-2 w-full flex justify-between">
                <div className="flex gap-2">
                  <button className="py-1 px-2 rounded-lg bg-[#DBDBDB]">
                    <img src="/icons/share.png" alt="Share" className="w-5 h-5" />
                  </button>
                  <button className="py-1 px-2 rounded-lg bg-[#DBDBDB]">
                    <img src="/icons/heart.png" alt="Favorite" className="w-5 h-5" />
                  </button>
                </div>
              </div>
            </div>

            {/* Thumbnails */}
            {thumbImgUrls.map((thumbUrl, index) => (
              <div key={`thumb-${index}`} className="relative h-full w-full">
                <div className="w-full h-full flex items-center justify-center">
                  <img 
                    src={thumbUrl} 
                    alt={`Thumbnail ${index + 1}`} 
                    className="max-w-full max-h-full object-contain"
                    onError={(e) => {
                      // If thumbnail fails to load, try the developer thumbnail URL
                      e.target.src = `http://localhost:8000/user-img/developer-post-thumb/${thumbImages[index]}`;
                      // If developer thumbnail fails, use default property image
                      e.target.onerror = () => {
                        e.target.src = "/property.png";
                        e.target.onerror = null; // Prevent infinite loop
                      };
                    }}
                  />
                </div>
                <div className="absolute top-2 px-2 w-full flex justify-between">
                  <div className="flex gap-2">
                    <button className="py-1 px-2 rounded-lg bg-[#DBDBDB]">
                      <img src="/icons/share.png" alt="Share" className="w-5 h-5" />
                    </button>
                    <button className="py-1 px-2 rounded-lg bg-[#DBDBDB]">
                      <img src="/icons/heart.png" alt="Favorite" className="w-5 h-5" />
                    </button>
                  </div>
                </div>
              </div>
            ))}
          </Carousel>
        </div>

        {/* Map Section */}
        <div className="lg:w-1/2 w-full aspect-square">
          <img 
            src="/map.png" 
            alt="Map" 
            className="w-full h-full object-cover rounded-lg"
          />
        </div>
      </div>

      {/* Navigation Section */}
      <div className="mt-4">
        <div className="flex gap-4 sm:gap-8 overflow-x-auto">
          {sections.map((item) => (
            <p
              key={item}
              onClick={() => setSelectedNav(item)}
              className={`
                font-semibold 
                pb-2 
                whitespace-nowrap
                ${item === selectedNav ? "border-brand border-b-2" : ""}
                text-sm 
                cursor-pointer
                hover:text-brand
                transition-colors
              `}
            >
              {item}
            </p>
          ))}
        </div>
      </div>
    </div>
  );
};

export default MapAndImages;